@@ -1,3 +1,26 @@
+//! A library for interacting with the Google Play API, strongly following [google play python API](https://github.com/NoMore201/googleplay-api.git) patterns.
+//!
+//! # Getting Started
+//!
+//! Interacting with the API starts off with initializing the API and logging in.
+//!
+//! ```rust
+//! let mut gpa = Gpapi::new("en_US", "UTC", "hero2lte");
+//! gpa.login("someone@gmail.com", "somepass").await);
+//! ```
+//!
+//! From here, you can get package details, get the URL to download a package, or use the library to download it.
+//!
+//! ```rust
+//! let details = gpa.details("com.instagram.android");
+//! println!("{:?}", details);
+//!
+//! let download_url = gpa.get_download_url("com.instagram.android", None);
+//! println!("{:?}", download_url);
+//!
+//! gpa.download("com.instagram.android", None, &Path::new("/tmp/testing")).await;
+//! ```
+
 mod consts;
 
 use std::collections::HashMap;
@@ -719,15 +742,19 @@ mod tests {
     #[test]
     fn login() {
         let enc = encrypt_login("foo", "bar").unwrap();
-        println!("encrypted: {:?}", base64::encode(&enc));
-        println!("base64_urlsafe: {:?}", base64_urlsafe(&enc));
+        assert!(base64::encode(&enc).starts_with("AFcb4K"));
+        assert_eq!(base64::encode(&enc).len(), 180);
+        assert!(!base64_urlsafe(&enc).contains("/"));
     }
 
     #[test]
     fn parse_form() {
         let form_reply = "FOO=BAR\nbaz=qux";
-        let x = parse_form_reply(&form_reply);
-        println!("form (parsed): {:?}", x);
+        let mut expected_reply = HashMap::new();
+        expected_reply.insert("baz".to_string(), "qux".to_string());
+        expected_reply.insert("foo".to_string(), "BAR".to_string());
+        let parsed_form_reply = parse_form_reply(&form_reply);
+        assert_eq!(expected_reply, parsed_form_reply);
     }
 
     mod gpapi {
@@ -738,6 +765,7 @@ mod tests {
         use googleplay_protobuf::BulkDetailsRequest;
 
         #[tokio::test]
+        #[ignore]
         async fn create_gpapi() {
             match (
                 env::var("GOOGLE_LOGIN"),
@@ -760,9 +788,9 @@ mod tests {
 
         #[test]
         fn test_protobuf() {
-            let mut x = BulkDetailsRequest::new();
-            x.docid = vec!["test".to_string()].into();
-            x.includeChildDocs = Some(true);
+            let mut bdr = BulkDetailsRequest::new();
+            bdr.docid = vec!["test".to_string()].into();
+            bdr.includeChildDocs = Some(true);
         }
     }
 }
